==> allegro4.4_4.4.2.orig.tar.gz: allegro4.4-4.4.2/demos/shooter/data.h <==
/* Allegro datafile object indexes, produced by grabber v3.11 */
/* Datafile: e:\allegro\demo\demo.dat */
/* Date: Fri Apr  9 15:55:51 1999 */
/* Do not hand edit! */

#define ASTA01                           0      /* RLE  */
#define ASTA02                           1      /* RLE  */
#define ASTA03                           2      /* RLE  */
#define ASTA04                           3      /* RLE  */
#define ASTA05                           4      /* RLE  */
#define ASTA06                           5      /* RLE  */
#define ASTA07                           6      /* RLE  */
#define ASTA08                           7      /* RLE  */
#define ASTA09                           8      /* RLE  */
#define ASTA10                           9      /* RLE  */
#define ASTA11                           10     /* RLE  */
#define ASTA12                           11     /* RLE  */
#define ASTA13                           12     /* RLE  */
#define ASTA14                           13     /* RLE  */
#define ASTA15                           14     /* RLE  */
#define ASTB01                           15     /* RLE  */
#define ASTB02                           16     /* RLE  */
#define ASTB03                           17     /* RLE  */
#define ASTB04                           18     /* RLE  */
#define ASTB05                           19     /* RLE  */
#define ASTB06                           20     /* RLE  */
#define ASTB07                           21     /* RLE  */
#define ASTB08                           22     /* RLE  */
#define ASTB09                           23     /* RLE  */
#define ASTB10                           24     /* RLE  */
#define ASTB11                           25     /* RLE  */
#define ASTB12                           26     /* RLE  */
#define ASTB13                           27     /* RLE  */
#define ASTB14                           28     /* RLE  */
#define ASTB15                           29     /* RLE  */
#define ASTC01                           30     /* RLE  */
#define ASTC02                           31     /* RLE  */
#define ASTC03                           32     /* RLE  */
#define ASTC04                           33     /* RLE  */
#define ASTC05                           34     /* RLE  */
#define ASTC06                           35     /* RLE  */
#define ASTC07                           36     /* RLE  */
#define ASTC08                           37     /* RLE  */
#define ASTC09                           38     /* RLE  */
#define ASTC10                           39     /* RLE  */
#define ASTC11                           40     /* RLE  */
#define ASTC12                           41     /* RLE  */
#define ASTC13                           42     /* RLE  */
#define ASTC14                           43     /* RLE  */
#define ASTC15                           44     /* RLE  */
#define BOOM_SPL                         45     /* SAMP */
#define DEATH_SPL                        46     /* SAMP */
#define END_FONT                         47     /* FONT */
#define ENGINE1                          48     /* RLE  */
#define ENGINE2                          49     /* RLE  */
#define ENGINE3                          50     /* RLE  */
#define ENGINE4                          51     /* RLE  */
#define ENGINE5                          52     /* RLE  */
#define ENGINE6                          53     /* RLE  */
#define ENGINE7                          54     /* RLE  */
#define ENGINE_SPL                       55     /* SAMP */
#define GAME_MUSIC                       56     /* MIDI */
#define GAME_PAL                         57     /* PAL  */
#define GO_BMP                           58     /* BMP  */
#define INTRO_ANIM                       59     /* FLIC */
#define INTRO_BMP_1                      60     /* BMP  */
#define INTRO_BMP_2                      61     /* BMP  */
#define INTRO_BMP_3                      62     /* BMP  */
#define INTRO_BMP_4                      63     /* BMP  */
#define INTRO_MUSIC                      64     /* MIDI */
#define INTRO_SPL                        65     /* SAMP */
#define ROCKET                           66     /* RLE  */
#define SHIP1                            67     /* RLE  */
#define SHIP2                            68     /* RLE  */
#define SHIP3                            69     /* RLE  */
#define SHIP4                            70     /* RLE  */
#define SHIP5                            71     /* RLE  */
#define SHOOT_SPL                        72     /* SAMP */
#define TITLE_BMP                        73     /* BMP  */
#define TITLE_FONT                       74     /* FONT */
#define TITLE_MUSIC                      75     /* MIDI */
#define TITLE_PAL                        76     /* PAL  */
#define WELCOME_SPL                      77     /* SAMP */

==> allegro5_5.2.9.1+dfsg.orig.tar.gz: allegro5-5.2.9.1/demos/shooter/data.h <==
/* Allegro datafile object indexes, produced by grabber v3.11 */
/* Datafile: e:\allegro\demo\demo.dat */
/* Date: Fri Apr  9 15:55:51 1999 */
/* Do not hand edit! */

#define ASTA01                           0      /* RLE  */
#define ASTA02                           1      /* RLE  */
#define ASTA03                           2      /* RLE  */
#define ASTA04                           3      /* RLE  */
#define ASTA05                           4      /* RLE  */
#define ASTA06                           5      /* RLE  */
#define ASTA07                           6      /* RLE  */
#define ASTA08                           7      /* RLE  */
#define ASTA09                           8      /* RLE  */
#define ASTA10                           9      /* RLE  */
#define ASTA11                           10     /* RLE  */
#define ASTA12                           11     /* RLE  */
#define ASTA13                           12     /* RLE  */
#define ASTA14                           13     /* RLE  */
#define ASTA15                           14     /* RLE  */
#define ASTB01                           15     /* RLE  */
#define ASTB02                           16     /* RLE  */
#define ASTB03                           17     /* RLE  */
#define ASTB04                           18     /* RLE  */
#define ASTB05                           19     /* RLE  */
#define ASTB06                           20     /* RLE  */
#define ASTB07                           21     /* RLE  */
#define ASTB08                           22     /* RLE  */
#define ASTB09                           23     /* RLE  */
#define ASTB10                           24     /* RLE  */
#define ASTB11                           25     /* RLE  */
#define ASTB12                           26     /* RLE  */
#define ASTB13                           27     /* RLE  */
#define ASTB14                           28     /* RLE  */
#define ASTB15                           29     /* RLE  */
#define ASTC01                           30     /* RLE  */
#define ASTC02                           31     /* RLE  */
#define ASTC03                           32     /* RLE  */
#define ASTC04                           33     /* RLE  */
#define ASTC05                           34     /* RLE  */
#define ASTC06                           35     /* RLE  */
#define ASTC07                           36     /* RLE  */
#define ASTC08                           37     /* RLE  */
#define ASTC09                           38     /* RLE  */
#define ASTC10                           39     /* RLE  */
#define ASTC11                           40     /* RLE  */
#define ASTC12                           41     /* RLE  */
#define ASTC13                           42     /* RLE  */
#define ASTC14                           43     /* RLE  */
#define ASTC15                           44     /* RLE  */
#define BOOM_SPL                         45     /* SAMP */
#define DEATH_SPL                        46     /* SAMP */
#define END_FONT                         47     /* FONT */
#define ENGINE1                          48     /* RLE  */
#define ENGINE2                          49     /* RLE  */
#define ENGINE3                          50     /* RLE  */
#define ENGINE4                          51     /* RLE  */
#define ENGINE5                          52     /* RLE  */
#define ENGINE6                          53     /* RLE  */
#define ENGINE7                          54     /* RLE  */
#define ENGINE_SPL                       55     /* SAMP */
#define GAME_MUSIC                       56     /* MIDI */
#define GAME_PAL                         57     /* PAL  */
#define GO_BMP                           58     /* BMP  */
#define INTRO_ANIM                       59     /* FLIC */
#define INTRO_BMP_1                      60     /* BMP  */
#define INTRO_BMP_2                      61     /* BMP  */
#define INTRO_BMP_3                      62     /* BMP  */
#define INTRO_BMP_4                      63     /* BMP  */
#define INTRO_MUSIC                      64     /* MIDI */
#define INTRO_SPL                        65     /* SAMP */
#define ROCKET                           66     /* RLE  */
#define SHIP1                            67     /* RLE  */
#define SHIP2                            68     /* RLE  */
#define SHIP3                            69     /* RLE  */
#define SHIP4                            70     /* RLE  */
#define SHIP5                            71     /* RLE  */
#define SHOOT_SPL                        72     /* SAMP */
#define TITLE_BMP                        73     /* BMP  */
#define TITLE_FONT                       74     /* FONT */
#define TITLE_MUSIC                      75     /* MIDI */
#define TITLE_PAL                        76     /* PAL  */
#define WELCOME_SPL                      77     /* SAMP */
#define DATA_COUNT                       78

extern DATAFILE *data;
void data_load(void);
void unload_datafile(void);
